Package: shinyTree
Type: Package
Title: jsTree Bindings for Shiny
Version: 0.2.6
Date: 2018-10-04
Authors@R: c(
  person(family="Trestle Technology, LLC", role="aut", email="cran@trestletechnology.net"),
  person("Jeff", "Allen", role="aut", email="cran@trestletechnology.net"),
  person(family="Institut de Radioprotection et de Sûreté Nucléaire", role=c("cph"), email = "yann.richet@irsn.fr"),
  person("Ivan", "Bozhanov", role=c("ctb", "cph"), comment = "jsTree"),
  person(family="The Dojo Foundation", role=c("ctb", "cph"), comment="require.js"),
  person(family="jQuery Foundation, Inc.", role=c("ctb", "cph")),
  person("Mike", "Schaffer", role=c("cre"), email="mschaff@gmail.com"),
  person("Timm", "Danker", role=c("ctb"), email="tidafr@carina.uberspace.de"),
  person("Michael", "Bell", role=c("ctb"), email="bell_michael_a@lilly.com"))
Description: Exposes bindings to jsTree -- a JavaScript library
    that supports interactive trees -- to enable a rich, editable trees in
    Shiny.
License: MIT + file LICENSE
Depends: R (>= 2.15.1), methods
Imports: shiny (>= 0.9.0), jsonlite
Suggests: testthat
BugReports: https://github.com/trestletech/shinyTree/issues
RoxygenNote: 6.0.1
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2018-10-05 00:47:13 UTC; mschaff
Author: Trestle Technology, LLC [aut],
  Jeff Allen [aut],
  Institut de Radioprotection et de Sûreté Nucléaire [cph],
  Ivan Bozhanov [ctb, cph] (jsTree),
  The Dojo Foundation [ctb, cph] (require.js),
  jQuery Foundation, Inc. [ctb, cph],
  Mike Schaffer [cre],
  Timm Danker [ctb],
  Michael Bell [ctb]
Maintainer: Mike Schaffer <mschaff@gmail.com>
Repository: CRAN
Date/Publication: 2018-10-05 15:10:03 UTC
Built: R 3.4.1; ; 2018-10-29 16:48:16 UTC; windows
