Package: shinyTree
Type: Package
Title: jsTree Bindings for Shiny
Version: 0.3.1
Date: 2023-7-21
Authors@R: c(
  person(family="Trestle Technology, LLC", role="aut", email="cran@trestletechnology.net"),
  person("Jeff", "Allen", role="aut", email="cran@trestletechnology.net"),
  person(family="Institut de Radioprotection et de Sûreté Nucléaire", role=c("cph"), email = "yann.richet@irsn.fr"),
  person("Ivan", "Bozhanov", role=c("ctb", "cph"), comment = "jsTree"),
  person(family="The Dojo Foundation", role=c("ctb", "cph"), comment="require.js"),
  person(family="jQuery Foundation, Inc.", role=c("ctb", "cph")),
  person("Mike", "Schaffer", role=c("ctb"), email="mschaff@gmail.com"),
  person("Timm", "Danker", role=c("ctb"), email="tidafr@carina.uberspace.de"),
  person("Michael", "Bell", role=c("cre"), email="bell_michael_a@lilly.com"),
  person("Sebastian", "Gatscha", role=c("ctb"), email="kona1@gmx.at"),
  person("Thorn", "Thaler", role = c("ctb"), email = "thorn.thaler@thothal.at"))
Maintainer: Michael Bell <bell_michael_a@lilly.com>
Description: Exposes bindings to jsTree -- a JavaScript library
    that supports interactive trees -- to enable a rich, editable trees in
    Shiny.
License: MIT + file LICENSE
Depends: R (>= 2.15.1), methods
Imports: shiny (>= 0.9.0), htmlwidgets, jsonlite, stringr, promises
Suggests: testthat, shinytest, data.tree
BugReports: https://github.com/shinyTree/shinyTree/issues
RoxygenNote: 7.2.3
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2023-08-07 16:36:45 UTC; c038195
Author: Trestle Technology, LLC [aut],
  Jeff Allen [aut],
  Institut de Radioprotection et de Sûreté Nucléaire [cph],
  Ivan Bozhanov [ctb, cph] (jsTree),
  The Dojo Foundation [ctb, cph] (require.js),
  jQuery Foundation, Inc. [ctb, cph],
  Mike Schaffer [ctb],
  Timm Danker [ctb],
  Michael Bell [cre],
  Sebastian Gatscha [ctb],
  Thorn Thaler [ctb]
Repository: CRAN
Date/Publication: 2023-08-07 18:30:02 UTC
Built: R 4.6.0; ; 2026-04-29 00:57:09 UTC; unix
